@@ -17,7 +17,7 @@
  *           Fax: +49 7123 / 14892
  *
  *
- *  $Id: dbdimp.c 1.1 Tue, 30 Sep 1997 01:28:08 +0200 joe $
+ *  $Id: dbdimp.c,v 1.1.1.1.2.4 1999/01/19 12:23:07 joe Exp $
  */
 
 
@@ -393,23 +393,27 @@ void dbd_init(dbistate_t* dbistate) {
 
 void do_error(SV* h, int rc, char* what) {
     D_imp_xxh(h);
+    STRLEN lna;
+
     SV *errstr = DBIc_ERRSTR(imp_xxh);
     sv_setiv(DBIc_ERR(imp_xxh), (IV)rc);	/* set err early	*/
     sv_setpv(errstr, what);
     DBIh_EVENT2(h, ERROR_event, DBIc_ERR(imp_xxh), errstr);
     if (dbis->debug >= 2)
 	fprintf(DBILOGFP, "%s error %d recorded: %s\n",
-		what, rc, SvPV(errstr,na));
+		what, rc, SvPV(errstr,lna));
 }
 void do_warn(SV* h, int rc, char* what) {
     D_imp_xxh(h);
+    STRLEN lna;
+
     SV *errstr = DBIc_ERRSTR(imp_xxh);
     sv_setiv(DBIc_ERR(imp_xxh), (IV)rc);	/* set err early	*/
     sv_setpv(errstr, what);
     DBIh_EVENT2(h, WARN_event, DBIc_ERR(imp_xxh), errstr);
     if (dbis->debug >= 2)
 	fprintf(DBILOGFP, "%s warning %d recorded: %s\n",
-		what, rc, SvPV(errstr,na));
+		what, rc, SvPV(errstr,lna));
     warn("%s", what);
 }
 #define doquietwarn(s)                                            \
@@ -450,6 +454,7 @@ void do_warn(SV* h, int rc, char* what) {
 int MyConnect(dbh_t *sock, char* unixSocket, char* host, char* port,
 	      char* user, char* password, char* dbname, imp_dbh_t *imp_dbh) {
     int portNr;
+    STRLEN lna;
 
     if (host && !*host) host = NULL;
     if (port && *port) {
@@ -485,13 +490,13 @@ int MyConnect(dbh_t *sock, char* unixSocket, char* host, char* port,
 				    FALSE))  &&
 		    *svp  &&  SvTRUE(*svp)) {
 		  mysql_options(*sock, MYSQL_READ_DEFAULT_FILE,
-				SvPV(*svp, na));
+				SvPV(*svp, lna));
 		}
 		if ((svp = hv_fetch(hv, "mysql_read_default_group", 24,
 				    FALSE))  &&
 		    *svp  &&  SvTRUE(*svp)) {
 		    mysql_options(*sock, MYSQL_READ_DEFAULT_GROUP,
-				  SvPV(*svp, na));
+				  SvPV(*svp, lna));
 		}
 	    }
         }
@@ -547,7 +552,7 @@ static int _MyLogin(imp_dbh_t *imp_dbh) {
     char* user;
     char* password;
     char* unixSocket = NULL;
-    STRLEN len;
+    STRLEN len, lna;
 
     sv = DBIc_IMP_DATA(imp_dbh);
     if (!sv  ||  !SvROK(sv)) {
@@ -566,7 +571,7 @@ static int _MyLogin(imp_dbh_t *imp_dbh) {
         host = NULL;
     }
     if ((svp = hv_fetch(hv, "port", 4, FALSE))) {
-        port = SvPV(*svp, na);
+        port = SvPV(*svp, lna);
     } else {
         port = NULL;
     }
@@ -587,19 +592,19 @@ static int _MyLogin(imp_dbh_t *imp_dbh) {
         password = NULL;
     }
     if ((svp = hv_fetch(hv, "database", 8, FALSE))) {
-        dbname = SvPV(*svp, na);
+        dbname = SvPV(*svp, lna);
     } else {
         dbname = NULL;
     }
 #ifdef DBD_MYSQL
     if ((svp = hv_fetch(hv, "mysql_socket", 12, FALSE))  &&
         *svp  &&  SvTRUE(*svp)) {
-        unixSocket = SvPV(*svp, na);
+        unixSocket = SvPV(*svp, lna);
     }
 #elif defined(IDX_TYPE)
     if ((svp = hv_fetch(hv, "msql_configfile", 15, FALSE))  &&
         *svp  &&  SvOK(*svp)) {
-        char* cf = SvPV(*svp, na);
+        char* cf = SvPV(*svp, lna);
         if (dbis->debug >= 2) {
             fprintf(DBILOGFP, "imp_dbh->MyLogin: Loading config file %s\n",
                     cf);
@@ -971,7 +976,6 @@ SV* dbd_db_FETCH_attrib(SV* dbh, imp_dbh_t* imp_dbh, SV* keysv) {
 int dbd_st_prepare(SV* sth, imp_sth_t* imp_sth, char* statement, SV* attribs) {
     int i;
 
-
     /*
      *  Count the number of parameters
      */
@@ -984,27 +988,18 @@ int dbd_st_prepare(SV* sth, imp_sth_t* imp_sth, char* statement, SV* attribs) {
     imp_sth->cda = NULL;
     imp_sth->currow = 0;
 #if defined(DBD_MYSQL)
-    imp_sth->use_mysql_use_result = 0;
+    {
+        SV** svp = DBD_ATTRIB_GET_SVP(attribs, "mysql_use_result", 16);
+        imp_sth->use_mysql_use_result = svp && SvTRUE(*svp);
+	if (dbis->debug >= 2)
+	    fprintf(DBILOGFP, "Setting mysql_use_result to %d\n",
+		    imp_sth->use_mysql_use_result);
+    }
 #endif
     for (i = 0;  i < AV_ATTRIB_LAST;  i++) {
 	imp_sth->av_attr[i] = Nullav;
     }
 
-#if defined(DBD_MYSQL)
-    /*
-     *  Check attributes
-     */
-    if (attribs  &&  SvTYPE(attribs) == SVt_RV) {
-        SV* sv = SvRV(attribs);
-	if (SvTYPE(sv) == SVt_PVHV) {
-	    SV** svp = hv_fetch((HV*) sv, "mysql_use_result", 16, FALSE);
-	    if (svp) {
-	        imp_sth->use_mysql_use_result = SvTRUE(*svp);
-	    }
-	}
-    }
-#endif
-
     /*
      *  Allocate memory for parameters
      */
@@ -2152,12 +2147,7 @@ SV* dbd_db_quote(SV* dbh, SV* str, SV* type) {
     STRLEN len;
 
     if (!SvOK(str)) {
-        static SV* nullStrSv = NULL;
-	if (!nullStrSv) {
-	    nullStrSv = newSVpv("NULL", 4);
-	}
-	SvREFCNT_inc(nullStrSv);
-	result = nullStrSv;
+        result = newSVpv("NULL", 4);
     } else {
         if (type  &&  SvOK(type)) {
 	    int i;
