@@ -17,7 +17,7 @@ use vars qw($QUIET @ISA @EXPORT @EXPORT_OK $VERSION $db_errstr);
 $db_errstr = '';
 $QUIET  = 0;
 @ISA    = qw(DBI); # Inherits Exporter and DynaLoader via DBI
-$VERSION = '1.21_08';
+$VERSION = '1.21_13';
 
 # @EXPORT is a relict from old times...
 @EXPORT = qw(
@@ -113,7 +113,10 @@ sub selectdb ($$) {
 
 sub listdbs ($) {
     my($self) = shift;
-    $self->{'drh'}->func($self->{'host'}, '_ListDBs');
+    my $drh = $self->{'drh'};
+    my @dbs = $drh->func($self->{'host'}, '_ListDBs');
+    $db_errstr = $drh->errstr();
+    @dbs;
 }
 
 sub listtables ($) {
@@ -155,14 +158,21 @@ sub listfields ($$) {
 
 sub query ($$) {
     my($self, $statement) = @_;
-    my($sth) = $self->{'dbh'}->prepare($statement);
-    my($result);
+    my $dbh = $self->{'dbh'};
+    my $sth = $dbh->prepare($statement);
+    if (!$sth) {
+	$db_errstr = $dbh->errstr();
+	return undef;
+    }
     $sth->{'PrintError'} = !$Mysql::QUIET;
-    if ($sth  &&  !($result = $sth->execute())) {
+    my $result = $sth->execute();
+    if (!$result) {
+	$db_errstr = $sth->errstr();
 	return undef;
     }
     $sth->{'CompatMode'} = 1;
     bless($sth, ref($self) . "::Statement");
+    undef $db_errstr;
     $sth;
 }
 
@@ -303,7 +313,8 @@ Msql / Mysql - Perl interfaces to the mSQL and mysql databases
   $sth = $dbh->listfields($table);
   $sth = $dbh->query($sql_statement);
 	
-  @arr = $sth->fetchrow;
+  @arr = $sth->fetchrow;	# Array context
+  $firstcol = $sth->fetchrow;	# Scalar context
   @arr = $sth->fetchcol($col_number);
   %hash = $sth->fetchhash;
 	
@@ -395,7 +406,12 @@ further information.
   @arr = $sth->fetchrow;
 
 returns an array of the values of the next row fetched from the
-server. Similar does
+server. Be carefull with context here! In scalar context the method
+behaves different than expected and returns the first column:
+
+  $firstcol = $sth->fetchrow; # Scalar context!
+
+Similar does
 
   %hash = $sth->fetchhash;
 
