@@ -7,15 +7,15 @@ package Mysql::Statement;
 use strict;
 use vars qw($OPTIMIZE $VERSION $AUTOLOAD);
 
-$VERSION = '1.21_08';
+$VERSION = '1.21_13';
 
 $OPTIMIZE = 0; # controls, which optimization we default to
 
 sub fetchrow ($) {
-    my($self) = shift;
-    my($ref) = $self->fetchrow_arrayref;
+    my $self = shift;
+    my $ref = $self->fetchrow_arrayref;
     if ($ref) {
-	@$ref;
+	wantarray ? @$ref : $ref->[0];
     } else {
 	();
     }
